========
calcdict
========

Overview
--------

Calculate values only when needed.

Installation
------------

To install calcdict, you can use `pip`. Open your terminal and run:

.. code-block:: bash

    pip install calcdict

License
-------

This project is licensed under the MIT License.

Credits
-------
- Author: Johannes
- Email: johannes-programming@posteo.org

Thank you for using calcdict!